/*
 *                         ManEdit Configuration List
 *
 *
 *	To add a new configuration item:
 *
 *	1. #define a new ME_CFG_PARM_ under "Parameters:" below.
 *
 *	2. Add the new parameter you just #defined in step 1 to the
 *	   Configuration List under "Configuration List:" below.
 *
 *	3. Add a the default setting for the new parameter in the
 *	   source file edv_core.c in the function
 *	   MENewDefaultConfigurationList().
 *
 *
 *	To edit an existing configuration item:
 *
 *	1. Edit the #define for the parameter under "Parameters:" below.
 *
 *	2. Edit the parameter in the Configuration List under
 *	   "Configuration List:" below.
 *
 */
#ifndef ME_CFG_LIST_H
#define ME_CFG_LIST_H


/*
 *	Parameters:
 */
#define ME_CFG_PARM_PATH_GLOBAL_DATA		"PathGlobalData"
#define ME_CFG_PARM_PATHS_MANPAGES		"PathsManualPages"
#define ME_CFG_PARM_PATH_TMP			"PathTemporary"
#define ME_CFG_PARM_PATH_LAST_OPEN		"PathLastOpen"
#define ME_CFG_PARM_PATH_LAST_SAVE_AS		"PathLastSaveAs"

#define ME_CFG_PARM_CMD_MANPAGE_INTERPRETER	"PathManPageInterpreter"

#define ME_CFG_PARM_STARTUP_EDITOR		"StartupEditor"
#define ME_CFG_PARM_STARTUP_VIEWER		"StartupViewer"

#define ME_CFG_PARM_RECORD_WIN_POS		"RecordWindowPosition"
#define ME_CFG_PARM_SHOW_TOOLTIPS		"ShowTooltips"

#define ME_CFG_PARM_EDITOR_X			"EditorX"
#define ME_CFG_PARM_EDITOR_Y			"EditorY"
#define ME_CFG_PARM_EDITOR_WIDTH		"EditorWidth"
#define ME_CFG_PARM_EDITOR_HEIGHT		"EditorHeight"
#define ME_CFG_PARM_EDITOR_PANED_POSITION	"EditorPannedPosition"
#define ME_CFG_PARM_EDITOR_TOOL_BAR_BUTTON_DECALS	"EditorToolBarButtonDecals"
#define ME_CFG_PARM_EDITOR_TOOL_BAR_RELIEF	"EditorToolBarRelief"
#define ME_CFG_PARM_EDITOR_SYNTAX_HIGHLIGHTING	"EditorSyntaxHighlighting"

#define ME_CFG_PARM_VIEWER_X			"ViewerX"
#define ME_CFG_PARM_VIEWER_Y			"ViewerY"
#define ME_CFG_PARM_VIEWER_WIDTH		"ViewerWidth"
#define ME_CFG_PARM_VIEWER_HEIGHT		"ViewerHeight"
#define ME_CFG_PARM_VIEWER_TOOL_BAR_BUTTON_DECALS	"ViewerToolBarButtonDecals"
#define ME_CFG_PARM_VIEWER_TOOL_BAR_RELIEF	"ViewerToolBarRelief"
#define ME_CFG_PARM_VIEWER_STARTUP_PAGE		"ViewerStartupPage"

#define ME_CFG_PARM_FONT_EDIT_STD		"FontEditable"
#define ME_CFG_PARM_FONT_MANPAGE_STD		"FontManPage"
#define ME_CFG_PARM_FONT_MANPAGE_BOLD		"FontManPageBold"
#define ME_CFG_PARM_FONT_MANPAGE_UNDERLINE	"FontManPageUnderline"

#define ME_CFG_PARM_COLOR_EDITOR_FG		"ColorEditableFG"
#define ME_CFG_PARM_COLOR_EDITOR_BG		"ColorEditableBG"
#define ME_CFG_PARM_COLOR_EDITOR_DELIMINATOR	"ColorEditableDeliminator"
#define ME_CFG_PARM_COLOR_EDITOR_TAG		"ColorEditableTag"
#define ME_CFG_PARM_COLOR_EDITOR_SYMBOL		"ColorEditableSymbol"

#define ME_CFG_PARM_COLOR_MANPAGE_FG		"ColorManPageFG"
#define ME_CFG_PARM_COLOR_MANPAGE_BG		"ColorManPageBG"
#define ME_CFG_PARM_COLOR_MANPAGE_BOLD		"ColorManPageBold"
#define ME_CFG_PARM_COLOR_MANPAGE_UNDERLINE	"ColorManPageUnderline"


#ifdef NEED_ME_CFG_LIST_SOURCE
/*
 *	Configuration List:
 *
 *	Values are in the format of:
 *
 *		<type> <param> <value_ptr>
 *
 *	See cfg.h for a list of valid values for <type>.
 *
 *	The <param> is one of ME_CFG_PARM_* found above.
 *
 *	The <value_ptr> should always be NULL here.
 *
 *	Note that the Configuration List (ME_CONFIGURATION_LIST) is
 *	only #defined if the source #defines NEED_ME_CFG_LIST_SOURCE.
 */
#define ME_CONFIGURATION_LIST						\
{									\
{ CFG_ITEM_TYPE_STRING,	ME_CFG_PARM_PATH_GLOBAL_DATA,		NULL },	\
{ CFG_ITEM_TYPE_STRING_LIST,	ME_CFG_PARM_PATHS_MANPAGES,	NULL },	\
{ CFG_ITEM_TYPE_STRING,	ME_CFG_PARM_PATH_TMP,			NULL },	\
{ CFG_ITEM_TYPE_STRING,	ME_CFG_PARM_PATH_LAST_OPEN,		NULL },	\
{ CFG_ITEM_TYPE_STRING,	ME_CFG_PARM_PATH_LAST_SAVE_AS,		NULL },	\
									\
{ CFG_ITEM_TYPE_STRING,	ME_CFG_PARM_CMD_MANPAGE_INTERPRETER,	NULL },	\
									\
{ CFG_ITEM_TYPE_UINT8,	ME_CFG_PARM_STARTUP_EDITOR,		NULL },	\
{ CFG_ITEM_TYPE_UINT8,	ME_CFG_PARM_STARTUP_VIEWER,		NULL }, \
									\
{ CFG_ITEM_TYPE_UINT8,	ME_CFG_PARM_RECORD_WIN_POS,		NULL },	\
{ CFG_ITEM_TYPE_UINT8,	ME_CFG_PARM_SHOW_TOOLTIPS,			NULL },	\
									\
{ CFG_ITEM_TYPE_INT32,	ME_CFG_PARM_EDITOR_X,			NULL },	\
{ CFG_ITEM_TYPE_INT32,	ME_CFG_PARM_EDITOR_Y,			NULL },	\
{ CFG_ITEM_TYPE_INT32,	ME_CFG_PARM_EDITOR_WIDTH,		NULL },	\
{ CFG_ITEM_TYPE_INT32,	ME_CFG_PARM_EDITOR_HEIGHT,		NULL },	\
{ CFG_ITEM_TYPE_INT32,	ME_CFG_PARM_EDITOR_PANED_POSITION,	NULL },	\
{ CFG_ITEM_TYPE_INT32,	ME_CFG_PARM_EDITOR_TOOL_BAR_BUTTON_DECALS,	NULL },	\
{ CFG_ITEM_TYPE_INT32,	ME_CFG_PARM_EDITOR_TOOL_BAR_RELIEF,	NULL },	\
{ CFG_ITEM_TYPE_UINT8,	ME_CFG_PARM_EDITOR_SYNTAX_HIGHLIGHTING,	NULL },	\
									\
{ CFG_ITEM_TYPE_INT32,	ME_CFG_PARM_VIEWER_X,			NULL },	\
{ CFG_ITEM_TYPE_INT32,	ME_CFG_PARM_VIEWER_Y,			NULL },	\
{ CFG_ITEM_TYPE_INT32,	ME_CFG_PARM_VIEWER_WIDTH,		NULL },	\
{ CFG_ITEM_TYPE_INT32,	ME_CFG_PARM_VIEWER_HEIGHT,		NULL },	\
{ CFG_ITEM_TYPE_INT32,	ME_CFG_PARM_VIEWER_TOOL_BAR_BUTTON_DECALS,	NULL },	\
{ CFG_ITEM_TYPE_INT32,	ME_CFG_PARM_VIEWER_TOOL_BAR_RELIEF,	NULL },	\
{ CFG_ITEM_TYPE_INT32,	ME_CFG_PARM_VIEWER_STARTUP_PAGE,	NULL },	\
									\
{ CFG_ITEM_TYPE_STRING,	ME_CFG_PARM_FONT_EDIT_STD,		NULL },	\
{ CFG_ITEM_TYPE_STRING,	ME_CFG_PARM_FONT_MANPAGE_STD,		NULL },	\
{ CFG_ITEM_TYPE_STRING,	ME_CFG_PARM_FONT_MANPAGE_BOLD,		NULL },	\
{ CFG_ITEM_TYPE_STRING,	ME_CFG_PARM_FONT_MANPAGE_UNDERLINE,	NULL },	\
									\
{ CFG_ITEM_TYPE_COLOR,	ME_CFG_PARM_COLOR_EDITOR_FG,		NULL },	\
{ CFG_ITEM_TYPE_COLOR,	ME_CFG_PARM_COLOR_EDITOR_BG,		NULL },	\
{ CFG_ITEM_TYPE_COLOR,	ME_CFG_PARM_COLOR_EDITOR_DELIMINATOR,	NULL },	\
{ CFG_ITEM_TYPE_COLOR,	ME_CFG_PARM_COLOR_EDITOR_TAG,		NULL },	\
{ CFG_ITEM_TYPE_COLOR,	ME_CFG_PARM_COLOR_EDITOR_SYMBOL,	NULL },	\
									\
{ CFG_ITEM_TYPE_COLOR,	ME_CFG_PARM_COLOR_MANPAGE_FG,		NULL },	\
{ CFG_ITEM_TYPE_COLOR,	ME_CFG_PARM_COLOR_MANPAGE_BG,		NULL },	\
{ CFG_ITEM_TYPE_COLOR,	ME_CFG_PARM_COLOR_MANPAGE_BOLD,		NULL },	\
{ CFG_ITEM_TYPE_COLOR,	ME_CFG_PARM_COLOR_MANPAGE_UNDERLINE,	NULL },	\
									\
									\
/* Last item must be all 0's. */					\
{ CFG_ITEM_TYPE_NONE,	NULL,					NULL }	\
}
#endif


/*
 *	Get Macros:
 */
#define ME_GET_B(_parm_)	( \
 (CFGItemListGetValueI(cfg_list, (_parm_))) ? (TRUE) : (FALSE) \
)
#define ME_GET_I(_parm_)	(CFGItemListGetValueI(cfg_list, (_parm_)))
#define ME_GET_L(_parm_)	(CFGItemListGetValueL(cfg_list, (_parm_)))
#define ME_GET_UL(_parm_)	(CFGItemListGetValueUL(cfg_list, (_parm_)))
#define ME_GET_F(_parm_)	(CFGItemListGetValueF(cfg_list, (_parm_)))
#define ME_GET_D(_parm_)	(CFGItemListGetValueD(cfg_list, (_parm_)))
#define ME_GET_S(_parm_)	(CFGItemListGetValueS(cfg_list, (_parm_)))
#define ME_GET_COLOR(_parm_)	(CFGItemListGetValueColor(cfg_list, (_parm_)))
#define ME_GET_INT_LIST(_parm_)	(CFGItemListGetValueIntList(cfg_list, (_parm_)))
#define ME_GET_STRING_LIST(_parm_)	(CFGItemListGetValueStringList(cfg_list, (_parm_)))
#define ME_GET_ACCELKEY_LIST(_parm_) (CFGItemListGetValueAccelkeyList(cfg_list, (_parm_)))
#define ME_GET_STYLE(_parm_)	(CFGItemListGetValueStyle(cfg_list, (_parm_)))
#define ME_GET_MENU(_parm_)	(CFGItemListGetValueMenu(cfg_list, (_parm_)))

/*
 *	Set Macros:
 */
#define ME_SET_B(_parm_,_v_)	(CFGItemListSetValueI( \
 cfg_list, (_parm_), (_v_) ? (TRUE) : (FALSE), (FALSE) \
))
#define ME_SET_I(_parm_,_v_)	(CFGItemListSetValueI( \
 cfg_list, (_parm_), (_v_), (FALSE) \
))
#define ME_SET_L(_parm_,_v_)	(CFGItemListSetValueL( \
 cfg_list, (_parm_), (_v_), (FALSE) \
))
#define ME_SET_UL(_parm_,_v_)	(CFGItemListSetValueUL( \
 cfg_list, (_parm_), (_v_), (FALSE) \
))
#define ME_SET_F(_parm_,_v_)	(CFGItemListSetValueF( \
 cfg_list, (_parm_), (_v_), (FALSE) \
))
#define ME_SET_D(_parm_,_v_)	(CFGItemListSetValueD( \
 cfg_list, (_parm_), (_v_), (FALSE) \
))
#define ME_SET_S(_parm_,_v_)	(CFGItemListSetValueS( \
 cfg_list, (_parm_), (_v_), (FALSE) \
))
#define ME_SET_COLOR(_parm_,_v_)	(CFGItemListSetValueColor( \
 cfg_list, (_parm_), (_v_), (FALSE) \
))
#define ME_SET_INT_LIST(_parm_,_v_)	(CFGItemListSetValueIntList( \
 cfg_list, (_parm_), (_v_), (FALSE) \
))
#define ME_SET_STRING_LIST(_parm_,_v_)	(CFGItemListSetValueStringList( \
 cfg_list, (_parm_), (_v_), (FALSE) \
))
#define ME_SET_ACCELKEY_LIST(_parm_,_v_) (CFGItemListSetValueAccelkeyList( \
 cfg_list, (_parm_), (_v_), (FALSE) \
))
#define ME_SET_STYLE(_parm_,_v_)	(CFGItemListSetValueStyle( \
 cfg_list, (_parm_), (_v_), (FALSE) \
))
#define ME_SET_MENU(_parm_,_v_)	(CFGItemListSetValueMenu( \
 cfg_list, (_parm_), (_v_), (FALSE) \
))


#endif	/* ME_CFG_LIST_H */
